Convection to Plate Heat Exchangers (single-phase) (ht.conv_plate)
=====================================================================

.. automodule:: ht.conv_plate
    :members:
    :undoc-members:
    :show-inheritance:
